/*
Copyright 2020 The Flux authors

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package flags

import (
	"fmt"
	"strings"
)

var supportedPublicKeyAlgorithms = []string{"rsa", "ecdsa", "ed25519"}

type PublicKeyAlgorithm string

func (a *PublicKeyAlgorithm) String() string {
	return string(*a)
}

func (a *PublicKeyAlgorithm) Set(str string) error {
	if strings.TrimSpace(str) == "" {
		return fmt.Errorf("no public key algorithm given, must be one of: %s",
			strings.Join(supportedPublicKeyAlgorithms, ", "))
	}
	for _, v := range supportedPublicKeyAlgorithms {
		if str == v {
			*a = PublicKeyAlgorithm(str)
			return nil
		}
	}
	return fmt.Errorf("unsupported public key algorithm '%s', must be one of: %s",
		str, strings.Join(supportedPublicKeyAlgorithms, ", "))
}

func (a *PublicKeyAlgorithm) Type() string {
	return "publicKeyAlgorithm"
}

func (a *PublicKeyAlgorithm) Description() string {
	return fmt.Sprintf("SSH public key algorithm (%s)", strings.Join(supportedPublicKeyAlgorithms, ", "))
}
